# GenExpA
It is a comprehensive tool based on the new workflow for qPCR data analysis. The NormFinder algorithm selects the best reference gene and GenExpA validates the biological robustness of the selected normalizer by working out coherence score for the individual target gene. The software performs target gene expression analysis enriched with statistical analyses and generates results in the form of ready-to-use graphs and tables. Please cite Janik, M.E. et al. (2018) RT-qPCR analysis of human melanoma progression-related genes – A novel workflow for selection and validation of candidate reference genes. Int J Biochem Cell Biol, 101, 12-18. This software was supported by the National Science Centre, Poland (grant number 2016/21/B/NZ3/00348).
